---
feature_story: FS_24_50_40_64
feature_title: arg types without envelope classes
feature_status: OBSOLETE
---

TODO: This is obsolete as it seems to be better to stick with creating an `envelope_class`.
      It is a bit of an overhead, but keeps things consistent.
      It is especially noticeable after using snake_case style for `data_envelope` prop names while still
      using CamelCase style for `envelope_class` names.
      Clean this up in the future.

Some arg types do not have meaningful associated `data_envelope`.

For example, `access_type` (`ro` or `rw`) - it is just a mode of operation
(and has nothing to do with target `data_envelope`).

To keep reusing the same suggestion search mechanism,
it is easier to create as many surrogate `data_envelope` with `envelope_class` = `access_type`
as there are discrete arg values within that arg type (just 2, in case of `access_type`: `ro` and `rw`).
